@@ -16,12 +16,12 @@ from scipy.sparse import issparse
 
 from .model.vae import VAE
 from .model.utils import EarlyStopping
-from .metrics import batch_entropy_mixing_score, silhouette
 from .logger import create_logger
 from .data_loader import load_data
+from .metrics import *
 
 from anndata import AnnData
-from sklearn.preprocessing import maxabs_scale, MaxAbsScaler
+from sklearn.preprocessing import MaxAbsScaler
 
 from glob import glob
 
@@ -277,13 +277,11 @@ def Run(
         pred_id=1,
         seed=124, 
         num_workers=4,
+        patience=30,
         batch_key='domain_id',
         source_name='source',
-        rep_celltype='cell_type',
-        umap=False,
+        model_info=False,
         verbose=False,
-        assess=False,
-        show=False,
     ):
 
     """
@@ -353,6 +351,8 @@ def Run(
         Only used when out=='predict' to choose a decoder to predict data. Default: 1
     seed
         Random seed for torch and numpy. Default: 124
+    patience
+        early stopping patience. Default: 10
     batch_key
         Name of batch in AnnData. Default: domain_id
     source_name
@@ -361,6 +361,8 @@ def Run(
         Names of cell-type annotation in AnnData. Default: 'cell_type'   
     umap
         If True, perform UMAP for visualization. Default: False
+    model_info
+        If True, show structures of encoder and decoders.
     verbose
         Verbosity, True or False. Default: False
     assess
@@ -398,6 +400,8 @@ def Run(
     else:
         device='cpu'
     
+    print('Device:', device)
+
     outdir = outdir+'/'
     os.makedirs(outdir+'/checkpoint', exist_ok=True)
     log = create_logger('', fh=outdir+'log.txt')
@@ -448,13 +452,7 @@ def Run(
             print(adata_cm)
             print('\n')
 
-        if save_OT:           
-            memory = 0
-            for i in range(n_domain):
-                if i != ref_id:
-                    memory += num_cell[i]*num_cell[ref_id]*32/(8*1e9) * 4
-
-            print('Warning! Saving Optimal Transport plan needs extra {:.2f} GB memory, please set save_OT=False if no enough memory!'.format(memory)) 
+        if save_OT:
             for i in range(n_domain):
                 if i != ref_id:
                     ns = num_cell[i]
@@ -462,8 +460,6 @@ def Run(
                     tran_tmp = np.ones((ns, nt)) / (ns * nt)
                     tran[i] = tran_tmp.astype(np.float32)
 
-                    print(tran[i].dtype)
-
                     print('Size of transport plan between datasets {} and {}:'.format(i, ref_id), np.shape(tran[i]))
 
         trainloader, testloader = load_data(
@@ -476,14 +472,14 @@ def Run(
             use_specific=use_specific, 
             domain_name=batch_key,
             batch_size=batch_size,
-            num_workers=4
+            num_workers=num_workers
         )
 
-        early_stopping = EarlyStopping(patience=10, checkpoint_file=outdir+'/checkpoint/model.pt')
+        early_stopping = EarlyStopping(patience=patience, checkpoint_file=outdir+'/checkpoint/model.pt')
         
         # encoder structure
         if enc is None:
-            enc = [['fc', 1024, 1, 'relu'],['fc', 16, '', '']]      
+            enc = [['fc', 1024, 1, 'relu'], ['fc', 16, '', '']]      
 
         # decoder structure
         dec = {} 
@@ -505,7 +501,8 @@ def Run(
         # init model
         model = VAE(enc, dec, ref_id=ref_id, n_domain=n_domain, mode=mode)
 
-        log.info('model\n'+model.__repr__())
+        if model_info:
+            log.info('model\n'+model.__repr__())
 
         model.fit(
             trainloader, 
@@ -570,47 +567,6 @@ def Run(
         elif out == 'predict':
             adata_cm.obsm[out] = model.encodeBatch(testloader, num_gene, pred_id=pred_id, device=device, mode=mode, out=out)
 
-
-    if umap: #and adata.shape[0]<1e6:
-        log.info('Run UMAP')
-        sc.settings.figdir = outdir
-        # sc.set_figure_params(dpi=200, fontsize=10)
- 
-        if mode == 'h':
-            sc.pp.neighbors(adata_cm, use_rep=out)
-            sc.tl.umap(adata_cm, min_dist=0.1)
-            sc.tl.leiden(adata_cm)
-            
-            cols = [source_name, rep_celltype]
-            color = [c for c in cols if c in adata_cm.obs]
-
-            if len(color) > 0:
-                sc.pl.umap(adata_cm, color=color, save='result.pdf', show=show)
- 
-            if assess:
-                if len(adata_cm.obs[batch_key].cat.categories) > 1:
-                    entropy_score = batch_entropy_mixing_score(adata_cm.obsm['X_umap'], adata_cm.obs[batch_key])
-                    log.info('batch_entropy_mixing_score: {:.3f}'.format(entropy_score))
-
-                if rep_celltype in adata_cm.obs:
-                    sil_score = silhouette(adata_cm.obsm['X_umap'], adata_cm.obs[rep_celltype].cat.codes)
-                    log.info("silhouette_score: {:.3f}".format(sil_score))
-
-        else:
-            log.info('Plot umap')
-            for i in range(n_domain-1):
-                adata_concat = adatas[i].concatenate(adatas[i+1])
-            sc.pp.neighbors(adata_concat, n_neighbors=30, use_rep=out)
-            sc.tl.umap(adata_concat, min_dist=0.1)
-            sc.pl.umap(adata_concat, color=[source_name, rep_celltype], save='specific.pdf', wspace=0.3, legend_fontsize=14, \
-                title=['',''], s=5, show=show)
-
-            entropy_score = batch_entropy_mixing_score(adata_concat.obsm['X_umap'], adata_concat.obs[source_name])
-            log.info('batch_entropy_mixing_score: {:.3f}'.format(entropy_score))
-            sil_score = silhouette(adata_concat.obsm['X_umap'], adata_concat.obs[rep_celltype].cat.codes)
-            log.info("silhouette_score: {:.3f}".format(sil_score))
-            
-
     if mode == 'h':
         if save_OT:
             return adata_cm, tran
