@@ -100,7 +100,7 @@ def silhouette(
         asw = (asw + 1) / 2
     return asw
 
-def label_transfer(ref, query, rep='latent', label='celltype'):
+def label_transfer(ref, query, rep='latent', label='cell_type'):
     """
     Label transfer
     
