@@ -279,6 +279,7 @@ class VAE(nn.Module):
 
                     for i, (x, idx) in tk0:
                         x = x.float().to(device)
+                        idx = idx.to(device)
 
                         x_list = []
                         num_sum = []
@@ -325,6 +326,7 @@ class VAE(nn.Module):
                     for i, (x,y,idx) in tk0:
 
                         x, y = x.float().to(device), y.long().to(device)    
+                        idx = idx.to(device)
 
                         if len(torch.unique(y)) < self.n_domain:
                             continue
@@ -349,7 +351,7 @@ class VAE(nn.Module):
                             idx_query[j] = idx[loc_query[j]] - sum(num_cell[0:j])
 
                             if save_OT:
-                                tran_batch[j] = torch.from_numpy(tran[j][idx_query[j]][:,idx_ref]).to(device)
+                                tran_batch[j] = torch.from_numpy(tran[j]).to(device)[idx_query[j]][:,idx_ref]
                             else:
                                 tran_batch[j] = None
 
@@ -379,8 +381,8 @@ class VAE(nn.Module):
                                 mu_dict[self.ref_id].detach(), var_dict[self.ref_id].detach(), Couple=Prior_batch, device=device)
 
                             if save_OT:
-                                t0 = np.repeat(idx_query[j], len(idx_ref)).reshape(len(idx_query[j]),len(idx_ref))
-                                t1 = np.tile(idx_ref, (len(idx_query[j]), 1))
+                                t0 = np.repeat(idx_query[j].cpu().numpy(), len(idx_ref)).reshape(len(idx_query[j]),len(idx_ref))
+                                t1 = np.tile(idx_ref.cpu().numpy(), (len(idx_query[j]), 1))
                                 tran[j][t0,t1] = tran_batch[j].cpu().numpy()
 
                             ot_loss += ot_loss_tmp
@@ -407,8 +409,10 @@ class VAE(nn.Module):
                     for i, (x, y, idx) in tk0:
 
                         x_c, y = x[:, 0:num_gene[self.n_domain]].float().to(device), y.long().to(device)  
+                        idx = idx.to(device)
                                                     
                         loc_ref = torch.where(y==self.ref_id)[0]
+
                         idx_ref = idx[loc_ref] - sum(num_cell[0:self.ref_id])
 
                         loc_query = {}
@@ -428,9 +432,9 @@ class VAE(nn.Module):
                                 if save_OT:
                                     if len(idx_query[j]) != 0:
                                         if (len(idx_query[j])) == 1:
-                                            tran_batch[j] = torch.from_numpy(tran[j][idx_query[j]][idx_ref]).to(device)
+                                            tran_batch[j] = torch.from_numpy(tran[j]).to(device)[idx_query[j]][idx_ref]
                                         else:
-                                            tran_batch[j] = torch.from_numpy(tran[j][idx_query[j]][:,idx_ref]).to(device)
+                                            tran_batch[j] = torch.from_numpy(tran[j]).to(device)[idx_query[j]][:,idx_ref]
                                 else:
                                     tran_batch[j] = None
 
@@ -456,14 +460,10 @@ class VAE(nn.Module):
 
                                 if len(loc[j])>0:
                                     if weight is None:
-                                        recon_loss += 1/self.n_domain * loss_func(recon_x_c[loc[j]], x_c[loc[j]]) * \
-                                        2000
-                                        # kl_loss += kl_div(mu[loc[j]], var[loc[j]])                               
+                                        recon_loss += 1/self.n_domain * loss_func(recon_x_c[loc[j]], x_c[loc[j]]) * 2000                            
                                     else:
                                         weight = weight.to(device)
-                                        recon_loss += 1/self.n_domain * F.binary_cross_entropy(recon_x_c[loc[j]], x_c[loc[j]], weight=weight[idx[j]]) * \
-                                        2000
-                                        # kl_loss += kl_div(mu[loc[j]], var[loc[j]], weight[idx[j]])
+                                        recon_loss += 1/self.n_domain * F.binary_cross_entropy(recon_x_c[loc[j]], x_c[loc[j]], weight=weight[idx[j]]) * 2000
 
                         kl_loss = kl_div(mu, var) 
                         if use_specific:
@@ -523,8 +523,8 @@ class VAE(nn.Module):
                                         )
 
                                     if save_OT:
-                                        t0 = np.repeat(idx_query[j], len(idx_ref)).reshape(len(idx_query[j]),len(idx_ref))
-                                        t1 = np.tile(idx_ref, (len(idx_query[j]), 1))
+                                        t0 = np.repeat(idx_query[j].cpu().numpy(), len(idx_ref)).reshape(len(idx_query[j]),len(idx_ref))
+                                        t1 = np.tile(idx_ref.cpu().numpy(), (len(idx_query[j]), 1))
                                         tran[j][t0,t1] = tran_batch[j].cpu().numpy()
 
                                     ot_loss += ot_loss_tmp
